To build, run `uv build` then upload wheels from the `dist` folder

Here is [a link to another file in the repo](another_file.md), and [another link](./another_file.md) and [another file][/another_file.md]